package orm_test

import (
	"database/sql"
	"testing"

	"github.com/codecup/orm"
	"github.com/stretchr/testify/assert"

	_ "github.com/mattn/go-sqlite3"
)

type SamplePost struct {
	ID       int64
	BodyText string
}

func (p SamplePost) ConfigureEntity(e *orm.EntityConfigurator) {
	e.Table("sample_posts")
}

var sampleDb *sql.DB

func setupSample() error {
	sampleDb, _ = sql.Open("sqlite3", ":memory:")
	sampleDb.Exec(`CREATE TABLE IF NOT EXISTS sample_posts (id INTEGER PRIMARY KEY, body_text text)`)
	return orm.SetupConnections(orm.ConnectionConfig{
		DB:       sampleDb,
		Driver:   orm.Drivers.SQLite3,
		Entities: []orm.Entity{&SamplePost{}},
	})
}

func TestSampleFind(t *testing.T) {
	err := setupSample()
	assert.NoError(t, err)
	sampleDb.Exec(`INSERT INTO sample_posts (body_text) VALUES ('t1')`)
	sampleDb.Exec(`INSERT INTO sample_posts (body_text) VALUES ('t2')`)

	post, err := orm.Find[SamplePost](1)
	assert.NoError(t, err)
	assert.Equal(t, "t1", post.BodyText)
	assert.Equal(t, int64(1), post.ID)

	post, err = orm.Find[SamplePost](2)
	assert.NoError(t, err)
	assert.Equal(t, "t2", post.BodyText)
	assert.Equal(t, int64(2), post.ID)
}
